@@ -1,21 +1,23 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "pc"
-#define HOST_OS "bsdi3.0"
+#define HOST_OS "bsdi3.1"
 #define HOST_OS_NAME "bsdi3"
-#define HOST_OS_VERSION "3.0"
+#define HOST_OS_VERSION "3.1"
 #define HOST_ARCH "i386"
-#define HOST_NAME "aurora.services.soscorp.com"
+#define HOST_NAME "tsunami"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sat Dec 26 07:17:10 EST 1998"
+#define CONFIG_DATE "Fri Jul  7 19:12:29 EDT 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0b2s4"
+#define VERSION "6.0.4s6"
 #define PACKAGE "am-utils"
-#define VERSION "6.0b2s4"
+#define VERSION "6.0.4s6"
 #define DEBUG 1
+#define HOST_HEADER_VERSION "3.1"
 #define YYTEXT_POINTER 1
+#define HAVE_LIBRPC 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_LIBGDBM 1
+#define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
@@ -24,12 +26,14 @@
 #define HAVE_BZERO 1
 #define HAVE_CLNT_CREATE 1
 #define HAVE_CLNT_SPCREATEERROR 1
+#define HAVE_CLOCK_GETTIME 1
 #define HAVE_FLOCK 1
 #define HAVE_GET_MYADDRESS 1
 #define HAVE_GETCWD 1
 #define HAVE_GETDOMAINNAME 1
 #define HAVE_GETDTABLESIZE 1
 #define HAVE_GETHOSTNAME 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
@@ -47,6 +51,7 @@
 #define HAVE_RMDIR 1
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
+#define HAVE_SETITIMER 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -64,6 +69,7 @@
 #define HAVE_UNAME 1
 #define HAVE_UNMOUNT 1
 #define HAVE_VFORK 1
+#define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
 #define HAVE_CLNT_SPERRNO 1
@@ -127,7 +133,6 @@
 #define HAVE_NFS_NFSMOUNT_H 1
 #define HAVE_NFS_NFSPROTO_H 1
 #define HAVE_NFS_RPCV2_H 1
-#define HAVE_NFS_RPCV2_H 1
 #define HAVE_RPC_PMAP_CLNT_H 1
 #define HAVE_RPC_PMAP_PROT_H 1
 #define HAVE_RPC_RPC_H 1
@@ -160,11 +165,15 @@
 #define HAVE_SYS_UIO_H 1
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_VNODE_H 1
+#define HAVE_UFS_UFS_UFSMOUNT_H 1
 #define HAVE_ASSERT_H 1
 #define HAVE_CTYPE_H 1
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
+#define HAVE_IFADDRS_H 1
+#define HAVE_IRS_H 1
 #define HAVE_GRP_H 1
+#define HAVE_HESIOD_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
@@ -184,7 +193,6 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define HAVE_ST_RDEV 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_bsdi3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
@@ -201,11 +209,14 @@
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
 #define cdfs_args_t struct iso_args
+#define mfs_args_t struct mfs_args
 #define pcfs_args_t struct msdosfs_args
+#define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
+#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
 #define HAVE_EXTERN_FREE 1
 #define HAVE_EXTERN_GETDOMAINNAME 1
@@ -214,16 +225,17 @@
 #define HAVE_EXTERN_GETLOGIN 1
 #define HAVE_EXTERN_GETPAGESIZE 1
 #define HAVE_EXTERN_GETWD 1
-#define HAVE_EXTERN_INNETGR 1
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
+#define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
+#define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
@@ -232,22 +244,20 @@
 #define HAVE_FIELD_PCFS_ARGS_T_GID 1
 #define HAVE_FIELD_PCFS_ARGS_T_MASK 1
 #define HAVE_FIELD_PCFS_ARGS_T_UID 1
+#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
 #define HAVE_FIELD_STRUCT_STATFS_F_FSTYPENAME 1
 #define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
 #define HAVE_FIELD_NFS_ARGS_T_PROTO 1
 #define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_FIELD_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
-#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
-#define HAVE_HESIOD_INIT 1
 #define HAVE_MAP_HESIOD 1
-#define HAVE_YP_GET_DEFAULT_DOMAIN 1
+#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
-#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
-#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
@@ -256,18 +266,19 @@
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
 #define HAVE_FS_UNIONFS 1
-#define HAVE_AM_FS_AUTO 1
-#define HAVE_AM_FS_DIRECT 1
-#define HAVE_AM_FS_TOPLVL 1
-#define HAVE_AM_FS_ERROR 1
-#define HAVE_AM_FS_INHERIT 1
-#define HAVE_AM_FS_PROGRAM 1
-#define HAVE_AM_FS_LINK 1
-#define HAVE_AM_FS_LINKX 1
-#define HAVE_AM_FS_HOST 1
-#define HAVE_AM_FS_NFSX 1
-#define HAVE_AM_FS_NFSL 1
-#define HAVE_AM_FS_UNION 1
+#define HAVE_FS_UMAPFS 1
+#define HAVE_AMU_FS_AUTO 1
+#define HAVE_AMU_FS_DIRECT 1
+#define HAVE_AMU_FS_TOPLVL 1
+#define HAVE_AMU_FS_ERROR 1
+#define HAVE_AMU_FS_INHERIT 1
+#define HAVE_AMU_FS_PROGRAM 1
+#define HAVE_AMU_FS_LINK 1
+#define HAVE_AMU_FS_LINKX 1
+#define HAVE_AMU_FS_HOST 1
+#define HAVE_AMU_FS_NFSX 1
+#define HAVE_AMU_FS_NFSL 1
+#define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS "nfs"
 #define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
 #define MOUNT_TYPE_UFS "ufs"
@@ -275,13 +286,15 @@
 #define MOUNT_TYPE_PCFS "msdos"
 #define MOUNT_TYPE_MFS "mfs"
 #define MOUNT_TYPE_UNIONFS MNT_UNION
+#define MOUNT_TYPE_UMAPFS "umap"
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs3"
 #define MNTTAB_TYPE_UFS "ufs"
 #define MNTTAB_TYPE_CDFS "cd9660"
 #define MNTTAB_TYPE_PCFS "msdos"
 #define MNTTAB_TYPE_MFS "mfs"
-#define MNTTAB_TYPE_UNIONFS "unionfs"
+#define MNTTAB_TYPE_UNIONFS "union"
+#define MNTTAB_TYPE_UMAPFS "umap"
 #define MNT2_GEN_OPT_ASYNC 0x40
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
@@ -304,5 +317,7 @@
 #define MNT2_NFS_OPT_SOFT 0x1
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
+#define MNT2_CDFS_OPT_EXTATT 0x4
+#define MNT2_CDFS_OPT_GENS 0x2
+#define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
-#define HAVE_GETMNTINFO 1
